@@ -13,11 +13,11 @@ from subtitle_sync.markScriptWithRareWordsTimestamp import (
 from subtitle_sync.utils.furtherSyncScript import furtherSyncScript
 
 
-def sync(movieTitle):
-    subtitle = open("{}.srt".format(movieTitle), "r")
+def sync(moviePath, subsPath):
+    subtitle = open(subsPath, "r")
     subtitle = list(srt.parse(subtitle.read()))
 
-    script = open("{}.json".format(movieTitle), "rb")
+    script = open(moviePath, "rb")
     script = json.load(script)
 
     nlp = spacy.load("en_core_web_lg")
@@ -46,23 +46,28 @@ def sync(movieTitle):
     #         print(content)
     #         print("------")
     #         minPrevTimestamp = min(content["timestamp"][0], minPrevTimestamp)
-
-    # file0 = open("mvp_results/{}_time.json".format(movieTitle), "w+")
-    # json.dump(scriptWithTimestamp, file0, indent=4, ensure_ascii=False)
+    return scriptWithTimestamp
 
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="Parse Screenplay PDF into JSON")
 
     parser.add_argument(
-        "-s",
+        "-m",
         metavar="screenplay",
         type=str,
-        help="screenplay PDF filename",
+        help="screenplay json path",
         required=True,
     )
 
+    parser.add_argument(
+        "-s", metavar="subs", type=str, help="subtitle json path", required=True,
+    )
+
     # start from skipPage set up by user.  default to 0
     args = parser.parse_args()
-    movieTitle = args.s
-    sync(movieTitle)
+    moviePath = args.m
+    subsPath = args.s
+    scriptWithTimestamp = sync(moviePath, subsPath)
+    file0 = open("{}.json".format(moviePath), "w+")
+    json.dump(scriptWithTimestamp, file0, indent=4, ensure_ascii=False)
